==> ydk_models_cisco_ios_xr-6.3.1-py2.py3-none-any.whl: ydk/models/cisco_ios_xr/Cisco_IOS_XR_upgrade_fpd_ng_act.py <==
""" Cisco_IOS_XR_upgrade_fpd_ng_act 

This module contains a collection of YANG definitions
for Cisco IOS\-XR upgrade\-fpd package action data.

This module contains definitions
for the following management objects\:
  fpd\: Field programmable device (FPD) operational data

Copyright (c) 2013\-2017 by Cisco Systems, Inc.
All rights reserved.

"""
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error



class UpgradeFpd(Entity):
    """
    Execute FPD upgrade
    
    .. attribute:: input
    
    	
    	**type**\:   :py:class:`Input <ydk.models.cisco_ios_xr.Cisco_IOS_XR_upgrade_fpd_ng_act.UpgradeFpd.Input>`
    
    

    """

    _prefix = 'upgrade-fpd-act'
    _revision = '2017-04-04'

    def __init__(self):
        super(UpgradeFpd, self).__init__()
        self._top_entity = None

        self.yang_name = "upgrade-fpd"
        self.yang_parent_name = "Cisco-IOS-XR-upgrade-fpd-ng-act"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self._child_container_classes = {}
        self._child_list_classes = {}

        self.input = UpgradeFpd.Input()
        self.input.parent = self
        self._children_name_map["input"] = "input"
        self._children_yang_names.add("input")
        self._segment_path = lambda: "Cisco-IOS-XR-upgrade-fpd-ng-act:upgrade-fpd"


    class Input(Entity):
        """
        
        
        .. attribute:: force
        
        	Force the upgrade process
        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: fpd
        
        	name of the fpd to be upgraded
        	**type**\:  str
        
        	**mandatory**\: True
        
        .. attribute:: location
        
        	Location of the FPD to be upgraded
        	**type**\:  str
        
        	**mandatory**\: True
        
        

        """

        _prefix = 'upgrade-fpd-act'
        _revision = '2017-04-04'

        def __init__(self):
            super(UpgradeFpd.Input, self).__init__()

            self.yang_name = "input"
            self.yang_parent_name = "upgrade-fpd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {}

            self.force = YLeaf(YType.empty, "force")

            self.fpd = YLeaf(YType.str, "fpd")

            self.location = YLeaf(YType.str, "location")
            self._segment_path = lambda: "input"
            self._absolute_path = lambda: "Cisco-IOS-XR-upgrade-fpd-ng-act:upgrade-fpd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(UpgradeFpd.Input, ['force', 'fpd', 'location'], name, value)

    def clone_ptr(self):
        self._top_entity = UpgradeFpd()
        return self._top_entity

==> ydk_models_cisco_ios_xr-6.4.1-py2.py3-none-any.whl: ydk/models/cisco_ios_xr/Cisco_IOS_XR_upgrade_fpd_ng_act.py <==
""" Cisco_IOS_XR_upgrade_fpd_ng_act 

This module contains a collection of YANG definitions
for Cisco IOS\-XR upgrade\-fpd package action data.

This module contains definitions
for the following management objects\:
  fpd\: Field programmable device (FPD) operational data

Copyright (c) 2013\-2017 by Cisco Systems, Inc.
All rights reserved.

"""
from collections import OrderedDict

from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YError, YModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error



class UpgradeFpd(Entity):
    """
    Execute FPD upgrade
    
    .. attribute:: input
    
    	
    	**type**\:  :py:class:`Input <ydk.models.cisco_ios_xr.Cisco_IOS_XR_upgrade_fpd_ng_act.UpgradeFpd.Input>`
    
    

    """

    _prefix = 'upgrade-fpd-act'
    _revision = '2017-04-04'

    def __init__(self):
        super(UpgradeFpd, self).__init__()
        self._top_entity = None

        self.yang_name = "upgrade-fpd"
        self.yang_parent_name = "Cisco-IOS-XR-upgrade-fpd-ng-act"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self.ylist_key_names = []
        self._child_classes = OrderedDict([])
        self._leafs = OrderedDict()

        self.input = UpgradeFpd.Input()
        self.input.parent = self
        self._children_name_map["input"] = "input"
        self._segment_path = lambda: "Cisco-IOS-XR-upgrade-fpd-ng-act:upgrade-fpd"


    class Input(Entity):
        """
        
        
        .. attribute:: location
        
        	Location of the FPD to be upgraded
        	**type**\: str
        
        	**mandatory**\: True
        
        .. attribute:: fpd
        
        	name of the fpd to be upgraded
        	**type**\: str
        
        	**mandatory**\: True
        
        .. attribute:: force
        
        	Force the upgrade process
        	**type**\: :py:class:`Empty<ydk.types.Empty>`
        
        

        """

        _prefix = 'upgrade-fpd-act'
        _revision = '2017-04-04'

        def __init__(self):
            super(UpgradeFpd.Input, self).__init__()

            self.yang_name = "input"
            self.yang_parent_name = "upgrade-fpd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([])
            self._leafs = OrderedDict([
                ('location', YLeaf(YType.str, 'location')),
                ('fpd', YLeaf(YType.str, 'fpd')),
                ('force', YLeaf(YType.empty, 'force')),
            ])
            self.location = None
            self.fpd = None
            self.force = None
            self._segment_path = lambda: "input"
            self._absolute_path = lambda: "Cisco-IOS-XR-upgrade-fpd-ng-act:upgrade-fpd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(UpgradeFpd.Input, ['location', 'fpd', 'force'], name, value)

    def clone_ptr(self):
        self._top_entity = UpgradeFpd()
        return self._top_entity
